@@ -4,6 +4,8 @@
 
 """
 
+from .image import Image
+from .iconlabel import IconLabel
 from .flowlayout import FlowLayout
 from .colorchooserbutton import ColorChooserButton
 from .filechooserbutton import FileChooserButton
@@ -20,7 +22,9 @@ from .radiodelegate import RadioDelegate
 from .selectionwidget import SelectionWidget
 from .codeeditor import CodeEditor
 
-__all__ = ["FlowLayout",
+__all__ = ["Image",
+           "IconLabel",
+           "FlowLayout",
            "ColorChooserButton",
            "FileChooserButton",
            "FontChooserButton",
@@ -32,7 +36,6 @@ __all__ = ["FlowLayout",
            "ButtonDelegate",
            "RadioDelegate",
            "SelectionWidget",
-           "Image",
            "ImageViewer",
            "MarkdownWindow",
            "CodeEditor"]
