@@ -3,8 +3,8 @@
 @author: Philipp Temminghoff
 """
 
-from typing import Optional
 import pathlib
+from typing import Optional
 
 from prettyqt import core, widgets
 
@@ -13,18 +13,33 @@ class FileChooserButton(widgets.Widget):
 
     value_changed = core.Signal(pathlib.Path)
 
-    def __init__(self, extensions=None, mode="save", parent=None):
+    def __init__(self, extensions=None, mode="save", file_mode="existing_files",
+                 root=None, parent=None):
+        """initialize FileChooserButton
+
+        Args:
+            extensions: list of allowed extensions (default: {None})
+            mode: Accept mode ("save" or "load") (default: {"save"})
+            file_mode: File mode ("existing_files", "existing_file", "any_file",
+                                  or "directory") (default: {"existing_files"})
+            parent: parent widget (default: {None})
+        """
         super().__init__(parent)
         self.path = None
         self.extensions = extensions
         self.mode = mode
+        self.file_mode = file_mode
+        self.root = root
         layout = widgets.BoxLayout("horizontal", self)
         layout.set_margin(0)
         self.lineedit = widgets.LineEdit()
         self.lineedit.set_read_only()
         layout += self.lineedit
         action = widgets.Action()
-        action.set_icon("mdi.file-outline")
+        if self.file_mode == "directory":
+            action.set_icon("mdi.folder-outline")
+        else:
+            action.set_icon("mdi.file-outline")
         action.triggered.connect(self.open_file)
 
         self.button = widgets.ToolButton()
@@ -43,11 +58,14 @@ class FileChooserButton(widgets.Widget):
 
     @core.Slot()
     def open_file(self):
-        dialog = widgets.FileDialog(parent=self, path_id="file_path")
-        dialog.set_accept_mode(self.mode)
+        dialog = widgets.FileDialog(parent=self,
+                                    path_id="file_path",
+                                    mode=self.mode,
+                                    path=self.root,
+                                    file_mode=self.file_mode)
         if self.extensions:
             dialog.set_filter(self.extensions)
-        if not dialog.open_file():
+        if not dialog.choose():
             return None
         self.set_path(dialog.selected_file())
         self.value_changed.emit(self.path)
