@@ -40,12 +40,30 @@ def test_abstracttablemodel():
     # qtmodeltester.check(model, force_py=True)
 
 
+def test_buffer():
+    buf = core.Buffer()
+    with buf.open_file("read_only"):
+        pass
+
+
 def test_date():
     date = core.Date(1, 1, 2000)
     with open("data.pkl", "wb") as jar:
         pickle.dump(date, jar)
     with open("data.pkl", "rb") as jar:
-        date = pickle.load(jar)
+        new = pickle.load(jar)
+    assert date == new
+
+
+def test_datetime():
+    date = core.Date(2000, 11, 11)
+    dt = core.DateTime(date)
+    with open("data.pkl", "wb") as jar:
+        pickle.dump(dt, jar)
+    with open("data.pkl", "rb") as jar:
+        new = pickle.load(jar)
+    assert dt == new
+    repr(dt)
 
 
 def test_dir():
@@ -58,6 +76,12 @@ def test_diriterator():
         pass
 
 
+def test_file():
+    buf = core.File()
+    with buf.open_file("read_only"):
+        pass
+
+
 def test_mimedata():
     mime_data = core.MimeData()
     mime_data.set_data("type a", "data")
@@ -108,6 +132,7 @@ def test_regexp():
         pickle.dump(regex, jar)
     with open("data.pkl", "rb") as jar:
         regex = pickle.load(jar)
+    repr(regex)
     a = list(regex.matches_in_text("0a4"))
     assert len(a) == 2
 
@@ -118,6 +143,7 @@ def test_regularexpression():
         pickle.dump(regex, jar)
     with open("data.pkl", "rb") as jar:
         regex = pickle.load(jar)
+    repr(regex)
     a = list(regex.matches_in_text("0a4"))
     assert len(a) == 2
 
@@ -128,7 +154,9 @@ def test_runnable():
 
 def test_settings():
     settings = core.Settings("1", "2")
+    settings.clear()
     settings.set_value("test", "value")
+    assert len(settings) == 1
     assert "test" in settings
     assert settings.value("test") == "value"
     with core.Settings("ab", "cd", settings_id="test") as s:
@@ -145,9 +173,14 @@ def test_settings():
     assert settings.get("test3") == "abc"
     del settings["test3"]
     path = pathlib.Path.cwd()
+    for i in settings:
+        pass
+
     settings.set_default_format("ini")
+    assert settings.get_default_format() == "ini"
     with pytest.raises(ValueError):
         settings.set_default_format("ino")
+    assert settings.get_scope() == "user"
     settings.set_path("native", "user", path)
     with pytest.raises(ValueError):
         settings.set_path("error", "user", path)
@@ -187,3 +220,9 @@ def test_timer():
 
 def test_translator():
     core.Translator()
+
+
+def test_url():
+    url = core.Url()
+    url.to_path()
+    assert not url.is_local_file()
