@@ -54,15 +54,17 @@ def test_dataset():
         string1 = fo.String(label="My first one", regex="[0-9]")
         string2 = fo.String(label="My second one", notempty=True)
         choiceitem = fo.Enum(label="A", choices=["A", "B"]).set_not_active("i1")
-        mchoiceitem = fo.MultipleChoiceItem(label="A", choices=["A", "B"])
+        mchoiceitem = fo.MultipleChoice(label="A", choices=["A", "B"])
         floatitem = fo.Float(label="FloatItem").set_active("i1")
         intitem = fo.Int(label="IntItem").set_active("i1")
         coloritem = fo.Color(label="ColorItem", value="green")
-        filesaveitem = fo.FileSaveItem(label="FileSaveItem")
-        buttonitem = fo.ButtonItem(label="FileSaveItem", callback=print)
+        fileitem = fo.File(label="File")
+        folderitem = fo.Folder(label="File")
+        buttonitem = fo.Button(label="Button", callback=print)
 
-    dlg = Test(icon="mdi.timer")
-    dlg.to_dict()
+    settings = Test(icon="mdi.timer")
+    settings.create_dialog()
+    settings.to_dict()
 
 
 def test_filechooserbutton():
@@ -85,6 +87,13 @@ def test_fontchooserbutton():
     repr(btn)
 
 
+def test_iconlabel():
+    w = custom_widgets.IconLabel()
+    w.set_text("test")
+    assert w.text() == "test"
+    repr(w)
+
+
 def test_inputandslider():
     w = custom_widgets.InputAndSlider()
     w.set_range(0, 10)
@@ -152,12 +161,22 @@ def test_popupinfo():
 
 def test_selectionwidget():
     widget = custom_widgets.SelectionWidget()
+
+    class Test(object):
+        pass
+    test = Test()
     items = {"Semicolon": ";",
-             "Tab": "\t",
-             "Comma": ","}
+             "Tab": "tab",
+             "Comma": ",",
+             "class": test}
     widget.add_items(items)
     widget.add_items(("a", "b"))
     widget.add_custom(label="test", regex=r"\S{1}")
+    radiobuttons = [k for k, v in widget.buttons.items()]
+    radiobuttons[1].click()
+    assert widget.get_value() == "tab"
+    radiobuttons[3].click()
+    assert widget.current_choice() == test
     for i in widget:
         pass
     widget.select_radio_by_data(";")
@@ -191,7 +210,9 @@ def test_spanslider(qtbot):
     slider.move_pressed_handle()
     qtbot.mouseClick(slider, QtCore.Qt.LeftButton)
     qtbot.mouseMove(slider, core.Point(20, 20))
+    qtbot.mouseMove(slider, core.Point(0, 0), delay=10)
     assert slider.movement_mode == "free"
+    slider.set_movement_mode("no_overlap")
 
 
 def test_waitingspinner():
